@@ -123,8 +123,7 @@ def tpt_line_with_apply(in_lines: list[str]) -> int:
     """vrací pozice řádek, kde je APPLY"""
     lines = []
     for i, line in enumerate(in_lines):
-        line = line.strip().upper()
-        if line == "APPLY":
+        if line.strip("' ").upper() == "APPLY":
             lines.append(i)
 
     if len(lines) == 0:
